@@ -6,7 +6,7 @@ pub mod common{
     pub use dochy_fs::common::get_hash_times;
     pub use dochy_fs::common::remove_hash_dir;
 
-    pub use dochy_fs::common::JSON_ARC_OPT;
+
     pub use dochy_fs::common::reserved_filename;
 
     pub use dochy_fs::common::FileData;
@@ -62,11 +62,5 @@ pub mod filesys{
     pub use dochy_fs::filesys::remove_dochy_file;
     pub use dochy_fs::filesys::force_update_and_get_info_us;
     pub use dochy_fs::filesys::SaveDirInfo;
-
-}
-
-pub mod error{
-    pub use dochy_fs::error::FsResult;
-    pub use dochy_fs::error::FsError;
 }
 
